<?php

namespace Drupal\system_monitor_examples\Plugin\SystemMonitorTask;

use Drupal\Core\Logger\RfcLogLevel;
use Drupal\system_monitor\Plugin\SystemMonitorTask\SystemMonitorTaskBase;

/**
 * A test System Monitor Task.
 *
 * @SystemMonitorTask(
 *   id = "system_monitor_examples_cron_check_task",
 *   label = @Translation("Check Cron Status"),
 *   description = @Translation("This task checks the last time system cron was run."),
 *   monitor_type = "system_monitor_examples_demo",
 *   tags = {
 *     "system_monitor_examples"
 *   }
 * )
 */
class SystemMonitorExamplesCronCheckTask extends SystemMonitorTaskBase {

  /**
   * The check to run for this System Monitor task.
   *
   * @return int
   *   The status value returned by the monitor task.
   */
  public function runTask() {
    $status = 0;
    $cron_last = \Drupal::state()->get('system.cron_last');
    if ($cron_last < strtotime('now -15 days')) {
      $status = RfcLogLevel::ALERT;
      $this->createOrUpdateIncident('Issue with system cron', 'System cron has not run in over 2 weeks.', $status);
    }
    elseif ($cron_last < strtotime('now -7 days')) {
      $status = RfcLogLevel::CRITICAL;
      $this->createOrUpdateIncident('Possible issue with system cron', 'System cron has not run in over 7 days.', $status);
    }
    elseif ($cron_last < strtotime('now -3 days')) {
      $status = RfcLogLevel::ERROR;
      $this->createOrUpdateIncident('Possible issue with system cron', 'System cron has not run in over 3 days.', $status);
    }
    elseif ($cron_last < strtotime('now -24 hours')) {
      $status = RfcLogLevel::WARNING;
      $this->createOrUpdateIncident('Possible issue with system cron', 'System cron has not run in over 24 hours.', $status);
    }
    else {
      $status = RfcLogLevel::INFO;
      $this->createOrUpdateIncident('System cron is healthy', 'System cron has run in the last 24 hours.', $status);
    }
    return $status;
  }

}
