<?php

namespace Drupal\system_monitor_examples\Plugin\SystemMonitorTask;

use Drupal\Core\Logger\RfcLogLevel;
use Drupal\system_monitor\Plugin\SystemMonitorTask\SystemMonitorTaskBase;

/**
 * A test System Monitor Task.
 *
 * @SystemMonitorTask(
 *   id = "system_monitor_examples_queue_check_task",
 *   label = @Translation("Check Queue Table"),
 *   description = @Translation("This task checks the system queue for stuck queue runners."),
 *   monitor_type = "system_monitor_examples_demo",
 *   tags = {
 *     "system_monitor_examples"
 *   }
 * )
 */
class SystemMonitorExamplesQueueCheckTask extends SystemMonitorTaskBase {

  /**
   * The check to run for this System Monitor task.
   *
   * @return int
   *   The status value returned by the monitor task.
   */
  public function runTask() {
    $status = 0;
    $results = \Drupal::database()->select('queue')
      ->condition('created', strtotime('now -15 days'), '<')
      ->countQuery()->execute()->fetchField();
    if ($results) {
      $status = RfcLogLevel::NOTICE;
      $this->createOrUpdateIncident('Possible stalled queue items', 'The queue table contains entries older than 15 days. It is possible a queue is stuck or stalled.', RfcLogLevel::NOTICE);
    }
    else {
      $status = RfcLogLevel::INFO;
      $this->createOrUpdateIncident('System queue is healthy', 'The queue table is empty or contains no entries older than 15 days.', RfcLogLevel::INFO);
    }
    return $status;
  }

}
